@@ -1,11 +1,5 @@
 from .connector import EscriptoriumConnector
 
-from .convenience_functions import (
-    copy_documents,
-    copy_documents_monitored,
-    copy_documents_generator,
-)
-
 from .connector_errors import (
     EscriptoriumConnectorError,
     EscriptoriumConnectorHttpError,
